# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: clientpb/client.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..commonpb import common_pb2 as commonpb_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='clientpb/client.proto',
  package='clientpb',
  syntax='proto3',
  serialized_options=b'Z-github.com/bishopfox/sliver/protobuf/clientpb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15\x63lientpb/client.proto\x12\x08\x63lientpb\x1a\x15\x63ommonpb/common.proto\"\x83\x01\n\x07Version\x12\r\n\x05Major\x18\x01 \x01(\x05\x12\r\n\x05Minor\x18\x02 \x01(\x05\x12\r\n\x05Patch\x18\x03 \x01(\x05\x12\x0e\n\x06\x43ommit\x18\x04 \x01(\t\x12\r\n\x05\x44irty\x18\x05 \x01(\x08\x12\x12\n\nCompiledAt\x18\x06 \x01(\x03\x12\n\n\x02OS\x18\x07 \x01(\t\x12\x0c\n\x04\x41rch\x18\x08 \x01(\t\"\xd8\x02\n\x07Session\x12\n\n\x02ID\x18\x01 \x01(\r\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x10\n\x08Hostname\x18\x03 \x01(\t\x12\x0c\n\x04UUID\x18\x04 \x01(\t\x12\x10\n\x08Username\x18\x05 \x01(\t\x12\x0b\n\x03UID\x18\x06 \x01(\t\x12\x0b\n\x03GID\x18\x07 \x01(\t\x12\n\n\x02OS\x18\x08 \x01(\t\x12\x0c\n\x04\x41rch\x18\t \x01(\t\x12\x11\n\tTransport\x18\n \x01(\t\x12\x15\n\rRemoteAddress\x18\x0b \x01(\t\x12\x0b\n\x03PID\x18\x0c \x01(\x05\x12\x10\n\x08\x46ilename\x18\r \x01(\t\x12\x13\n\x0bLastCheckin\x18\x0e \x01(\t\x12\x10\n\x08\x41\x63tiveC2\x18\x0f \x01(\t\x12\x0f\n\x07Version\x18\x10 \x01(\t\x12\x0f\n\x07\x45vasion\x18\x11 \x01(\x08\x12\x0e\n\x06IsDead\x18\x12 \x01(\x08\x12\x19\n\x11ReconnectInterval\x18\x13 \x01(\r\x12\x10\n\x08ProxyURL\x18\x14 \x01(\t\";\n\tImplantC2\x12\x10\n\x08Priority\x18\x01 \x01(\r\x12\x0b\n\x03URL\x18\x02 \x01(\t\x12\x0f\n\x07Options\x18\x03 \x01(\t\"\xd4\x05\n\rImplantConfig\x12\x0c\n\x04GOOS\x18\x01 \x01(\t\x12\x0e\n\x06GOARCH\x18\x02 \x01(\t\x12\x0c\n\x04Name\x18\x03 \x01(\t\x12\x0e\n\x06\x43\x41\x43\x65rt\x18\x04 \x01(\t\x12\x0c\n\x04\x43\x65rt\x18\x05 \x01(\t\x12\x0b\n\x03Key\x18\x06 \x01(\t\x12\r\n\x05\x44\x65\x62ug\x18\x07 \x01(\x08\x12\x0f\n\x07\x45vasion\x18\x1f \x01(\x08\x12\x18\n\x10ObfuscateSymbols\x18\x1e \x01(\x08\x12\x18\n\x10WGImplantPrivKey\x18! \x01(\t\x12\x16\n\x0eWGServerPubKey\x18\" \x01(\t\x12\x13\n\x0bWGPeerTunIP\x18# \x01(\t\x12\x19\n\x11WGKeyExchangePort\x18$ \x01(\r\x12\x16\n\x0eWGTcpCommsPort\x18% \x01(\r\x12\x19\n\x11ReconnectInterval\x18\x08 \x01(\r\x12\x1b\n\x13MaxConnectionErrors\x18\t \x01(\r\x12\x1f\n\x02\x43\x32\x18\n \x03(\x0b\x32\x13.clientpb.ImplantC2\x12\x15\n\rCanaryDomains\x18\x0b \x03(\t\x12\x19\n\x11LimitDomainJoined\x18\x14 \x01(\x08\x12\x15\n\rLimitDatetime\x18\x15 \x01(\t\x12\x15\n\rLimitHostname\x18\x16 \x01(\t\x12\x15\n\rLimitUsername\x18\x17 \x01(\t\x12\x17\n\x0fLimitFileExists\x18  \x01(\t\x12\x34\n\x06\x46ormat\x18\x19 \x01(\x0e\x32$.clientpb.ImplantConfig.OutputFormat\x12\x13\n\x0bIsSharedLib\x18\x1a \x01(\x08\x12\x10\n\x08\x46ileName\x18\x1b \x01(\t\x12\x11\n\tIsService\x18\x1c \x01(\x08\x12\x13\n\x0bIsShellcode\x18\x1d \x01(\x08\"J\n\x0cOutputFormat\x12\x0e\n\nSHARED_LIB\x10\x00\x12\r\n\tSHELLCODE\x10\x01\x12\x0e\n\nEXECUTABLE\x10\x02\x12\x0b\n\x07SERVICE\x10\x03\"\x8f\x01\n\rImplantBuilds\x12\x35\n\x07\x43onfigs\x18\x01 \x03(\x0b\x32$.clientpb.ImplantBuilds.ConfigsEntry\x1aG\n\x0c\x43onfigsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.clientpb.ImplantConfig:\x02\x38\x01\"\x19\n\tDeleteReq\x12\x0c\n\x04Name\x18\x01 \x01(\t\"\x81\x01\n\tDNSCanary\x12\x13\n\x0bImplantName\x18\x01 \x01(\t\x12\x0e\n\x06\x44omain\x18\x02 \x01(\t\x12\x11\n\tTriggered\x18\x03 \x01(\x08\x12\x16\n\x0e\x46irstTriggered\x18\x04 \x01(\t\x12\x15\n\rLatestTrigger\x18\x05 \x01(\t\x12\r\n\x05\x43ount\x18\x06 \x01(\r\"1\n\x08\x43\x61naries\x12%\n\x08\x43\x61naries\x18\x01 \x03(\x0b\x32\x13.clientpb.DNSCanary\"\x18\n\nUniqueWGIP\x12\n\n\x02IP\x18\x01 \x01(\t\"G\n\x0eImplantProfile\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\'\n\x06\x43onfig\x18\x02 \x01(\x0b\x32\x17.clientpb.ImplantConfig\"=\n\x0fImplantProfiles\x12*\n\x08Profiles\x18\x01 \x03(\x0b\x32\x18.clientpb.ImplantProfile\"$\n\rRegenerateReq\x12\x13\n\x0bImplantName\x18\x01 \x01(\t\"e\n\x03Job\x12\n\n\x02ID\x18\x01 \x01(\r\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x13\n\x0b\x44\x65scription\x18\x03 \x01(\t\x12\x10\n\x08Protocol\x18\x04 \x01(\t\x12\x0c\n\x04Port\x18\x05 \x01(\r\x12\x0f\n\x07\x44omains\x18\x06 \x03(\t\"%\n\x04Jobs\x12\x1d\n\x06\x41\x63tive\x18\x01 \x03(\x0b\x32\r.clientpb.Job\"\x18\n\nKillJobReq\x12\n\n\x02ID\x18\x01 \x01(\r\"&\n\x07KillJob\x12\n\n\x02ID\x18\x01 \x01(\r\x12\x0f\n\x07Success\x18\x02 \x01(\x08\"A\n\x0fMTLSListenerReq\x12\x0c\n\x04Host\x18\x01 \x01(\t\x12\x0c\n\x04Port\x18\x02 \x01(\r\x12\x12\n\nPersistent\x18\x03 \x01(\x08\"\x1d\n\x0cMTLSListener\x12\r\n\x05JobID\x18\x01 \x01(\r\"`\n\rWGListenerReq\x12\x0c\n\x04Port\x18\x01 \x01(\r\x12\r\n\x05TunIP\x18\x02 \x01(\t\x12\r\n\x05NPort\x18\x03 \x01(\r\x12\x0f\n\x07KeyPort\x18\x04 \x01(\r\x12\x12\n\nPersistent\x18\x05 \x01(\x08\"\x1b\n\nWGListener\x12\r\n\x05JobID\x18\x01 \x01(\r\"c\n\x0e\x44NSListenerReq\x12\x0f\n\x07\x44omains\x18\x01 \x03(\t\x12\x10\n\x08\x43\x61naries\x18\x02 \x01(\x08\x12\x0c\n\x04Host\x18\x03 \x01(\t\x12\x0c\n\x04Port\x18\x04 \x01(\r\x12\x12\n\nPersistent\x18\x05 \x01(\x08\"\x1c\n\x0b\x44NSListener\x12\r\n\x05JobID\x18\x01 \x01(\r\"\x9b\x01\n\x0fHTTPListenerReq\x12\x0e\n\x06\x44omain\x18\x01 \x01(\t\x12\x0c\n\x04Host\x18\x02 \x01(\t\x12\x0c\n\x04Port\x18\x03 \x01(\r\x12\x0e\n\x06Secure\x18\x04 \x01(\x08\x12\x0f\n\x07Website\x18\x05 \x01(\t\x12\x0c\n\x04\x43\x65rt\x18\x06 \x01(\x0c\x12\x0b\n\x03Key\x18\x07 \x01(\x0c\x12\x0c\n\x04\x41\x43ME\x18\x08 \x01(\x08\x12\x12\n\nPersistent\x18\t \x01(\x08\"E\n\rNamedPipesReq\x12\x10\n\x08PipeName\x18\x10 \x01(\t\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"P\n\nNamedPipes\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12\x0b\n\x03\x45rr\x18\x02 \x01(\t\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"B\n\x0bTCPPivotReq\x12\x0f\n\x07\x41\x64\x64ress\x18\x10 \x01(\t\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"N\n\x08TCPPivot\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12\x0b\n\x03\x45rr\x18\x02 \x01(\t\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"\x1d\n\x0cHTTPListener\x12\r\n\x05JobID\x18\x01 \x01(\r\"/\n\x08Sessions\x12#\n\x08Sessions\x18\x01 \x03(\x0b\x32\x11.clientpb.Session\"0\n\rUpdateSession\x12\x11\n\tSessionID\x18\x01 \x01(\r\x12\x0c\n\x04Name\x18\x02 \x01(\t\"6\n\x0bGenerateReq\x12\'\n\x06\x43onfig\x18\x01 \x01(\x0b\x32\x17.clientpb.ImplantConfig\"(\n\x08Generate\x12\x1c\n\x04\x46ile\x18\x01 \x01(\x0b\x32\x0e.commonpb.File\"\x80\x01\n\x06MSFReq\x12\x0f\n\x07Payload\x18\x01 \x01(\t\x12\r\n\x05LHost\x18\x02 \x01(\t\x12\r\n\x05LPort\x18\x03 \x01(\r\x12\x0f\n\x07\x45ncoder\x18\x04 \x01(\t\x12\x12\n\nIterations\x18\x05 \x01(\x05\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"\x93\x01\n\x0cMSFRemoteReq\x12\x0f\n\x07Payload\x18\x01 \x01(\t\x12\r\n\x05LHost\x18\x02 \x01(\t\x12\r\n\x05LPort\x18\x03 \x01(\r\x12\x0f\n\x07\x45ncoder\x18\x04 \x01(\t\x12\x12\n\nIterations\x18\x05 \x01(\x05\x12\x0b\n\x03PID\x18\x08 \x01(\r\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"\x91\x01\n\x11StagerListenerReq\x12)\n\x08Protocol\x18\x01 \x01(\x0e\x32\x17.clientpb.StageProtocol\x12\x0c\n\x04Host\x18\x02 \x01(\t\x12\x0c\n\x04Port\x18\x03 \x01(\r\x12\x0c\n\x04\x44\x61ta\x18\x04 \x01(\x0c\x12\x0c\n\x04\x43\x65rt\x18\x05 \x01(\x0c\x12\x0b\n\x03Key\x18\x06 \x01(\x0c\x12\x0c\n\x04\x41\x43ME\x18\x07 \x01(\x08\"\x1f\n\x0eStagerListener\x12\r\n\x05JobID\x18\x01 \x01(\r\"H\n\x0fShellcodeRDIReq\x12\x0c\n\x04\x44\x61ta\x18\x01 \x01(\x0c\x12\x14\n\x0c\x46unctionName\x18\x02 \x01(\t\x12\x11\n\tArguments\x18\x03 \x01(\t\"\x1c\n\x0cShellcodeRDI\x12\x0c\n\x04\x44\x61ta\x18\x01 \x01(\x0c\"\x91\x01\n\x0cMsfStagerReq\x12\x0c\n\x04\x41rch\x18\x01 \x01(\t\x12\x0e\n\x06\x46ormat\x18\x02 \x01(\t\x12\x0c\n\x04Port\x18\x03 \x01(\r\x12\x0c\n\x04Host\x18\x04 \x01(\t\x12\n\n\x02OS\x18\x05 \x01(\t\x12)\n\x08Protocol\x18\x06 \x01(\x0e\x32\x17.clientpb.StageProtocol\x12\x10\n\x08\x42\x61\x64\x43hars\x18\x07 \x03(\t\")\n\tMsfStager\x12\x1c\n\x04\x46ile\x18\x01 \x01(\x0b\x32\x0e.commonpb.File\"s\n\x0cGetSystemReq\x12\x16\n\x0eHostingProcess\x18\x01 \x01(\t\x12\'\n\x06\x43onfig\x18\x02 \x01(\x0b\x32\x17.clientpb.ImplantConfig\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"f\n\nMigrateReq\x12\x0b\n\x03Pid\x18\x01 \x01(\r\x12\'\n\x06\x43onfig\x18\x02 \x01(\x0b\x32\x17.clientpb.ImplantConfig\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"5\n\x0f\x43reateTunnelReq\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"7\n\x0c\x43reateTunnel\x12\x11\n\tSessionID\x18\x01 \x01(\r\x12\x14\n\x08TunnelID\x18\x08 \x01(\x04\x42\x02\x30\x01\"J\n\x0e\x43loseTunnelReq\x12\x14\n\x08TunnelID\x18\x08 \x01(\x04\x42\x02\x30\x01\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"H\n\x06\x43lient\x12\n\n\x02ID\x18\x01 \x01(\r\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12$\n\x08Operator\x18\x03 \x01(\x0b\x32\x12.clientpb.Operator\"\x97\x01\n\x05\x45vent\x12\x11\n\tEventType\x18\x01 \x01(\t\x12\"\n\x07Session\x18\x02 \x01(\x0b\x32\x11.clientpb.Session\x12\x1a\n\x03Job\x18\x03 \x01(\x0b\x32\r.clientpb.Job\x12 \n\x06\x43lient\x18\x04 \x01(\x0b\x32\x10.clientpb.Client\x12\x0c\n\x04\x44\x61ta\x18\x05 \x01(\x0c\x12\x0b\n\x03\x45rr\x18\x06 \x01(\t\"2\n\tOperators\x12%\n\tOperators\x18\x01 \x03(\x0b\x32\x12.clientpb.Operator\"(\n\x08Operator\x12\x0e\n\x06Online\x18\x01 \x01(\x08\x12\x0c\n\x04Name\x18\x02 \x01(\t\"R\n\nWebContent\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x13\n\x0b\x43ontentType\x18\x02 \x01(\t\x12\x10\n\x04Size\x18\x03 \x01(\x04\x42\x02\x30\x01\x12\x0f\n\x07\x43ontent\x18\t \x01(\x0c\"\xa5\x01\n\x11WebsiteAddContent\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12;\n\x08\x43ontents\x18\x02 \x03(\x0b\x32).clientpb.WebsiteAddContent.ContentsEntry\x1a\x45\n\rContentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.clientpb.WebContent:\x02\x38\x01\"3\n\x14WebsiteRemoveContent\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\r\n\x05Paths\x18\x02 \x03(\t\"\x91\x01\n\x07Website\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x31\n\x08\x43ontents\x18\x02 \x03(\x0b\x32\x1f.clientpb.Website.ContentsEntry\x1a\x45\n\rContentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.clientpb.WebContent:\x02\x38\x01\"/\n\x08Websites\x12#\n\x08Websites\x18\x01 \x03(\x0b\x32\x11.clientpb.Website\"h\n\x0eWGClientConfig\x12\x14\n\x0cServerPubKey\x18\x01 \x01(\t\x12\x18\n\x10\x43lientPrivateKey\x18\x02 \x01(\t\x12\x14\n\x0c\x43lientPubKey\x18\x03 \x01(\t\x12\x10\n\x08\x43lientIP\x18\x04 \x01(\t*-\n\rStageProtocol\x12\x07\n\x03TCP\x10\x00\x12\x08\n\x04HTTP\x10\x01\x12\t\n\x05HTTPS\x10\x02\x42/Z-github.com/bishopfox/sliver/protobuf/clientpbb\x06proto3'
  ,
  dependencies=[commonpb_dot_common__pb2.DESCRIPTOR,])

_STAGEPROTOCOL = _descriptor.EnumDescriptor(
  name='StageProtocol',
  full_name='clientpb.StageProtocol',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TCP', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTPS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5230,
  serialized_end=5275,
)
_sym_db.RegisterEnumDescriptor(_STAGEPROTOCOL)

StageProtocol = enum_type_wrapper.EnumTypeWrapper(_STAGEPROTOCOL)
TCP = 0
HTTP = 1
HTTPS = 2


_IMPLANTCONFIG_OUTPUTFORMAT = _descriptor.EnumDescriptor(
  name='OutputFormat',
  full_name='clientpb.ImplantConfig.OutputFormat',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SHARED_LIB', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHELLCODE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXECUTABLE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERVICE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1251,
  serialized_end=1325,
)
_sym_db.RegisterEnumDescriptor(_IMPLANTCONFIG_OUTPUTFORMAT)


_VERSION = _descriptor.Descriptor(
  name='Version',
  full_name='clientpb.Version',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Major', full_name='clientpb.Version.Major', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Minor', full_name='clientpb.Version.Minor', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Patch', full_name='clientpb.Version.Patch', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Commit', full_name='clientpb.Version.Commit', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Dirty', full_name='clientpb.Version.Dirty', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='CompiledAt', full_name='clientpb.Version.CompiledAt', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='OS', full_name='clientpb.Version.OS', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Arch', full_name='clientpb.Version.Arch', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59,
  serialized_end=190,
)


_SESSION = _descriptor.Descriptor(
  name='Session',
  full_name='clientpb.Session',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='clientpb.Session.ID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Name', full_name='clientpb.Session.Name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Hostname', full_name='clientpb.Session.Hostname', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='UUID', full_name='clientpb.Session.UUID', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Username', full_name='clientpb.Session.Username', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='UID', full_name='clientpb.Session.UID', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='GID', full_name='clientpb.Session.GID', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='OS', full_name='clientpb.Session.OS', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Arch', full_name='clientpb.Session.Arch', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Transport', full_name='clientpb.Session.Transport', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='RemoteAddress', full_name='clientpb.Session.RemoteAddress', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='PID', full_name='clientpb.Session.PID', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Filename', full_name='clientpb.Session.Filename', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='LastCheckin', full_name='clientpb.Session.LastCheckin', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ActiveC2', full_name='clientpb.Session.ActiveC2', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Version', full_name='clientpb.Session.Version', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Evasion', full_name='clientpb.Session.Evasion', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='IsDead', full_name='clientpb.Session.IsDead', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ReconnectInterval', full_name='clientpb.Session.ReconnectInterval', index=18,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ProxyURL', full_name='clientpb.Session.ProxyURL', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=193,
  serialized_end=537,
)


_IMPLANTC2 = _descriptor.Descriptor(
  name='ImplantC2',
  full_name='clientpb.ImplantC2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Priority', full_name='clientpb.ImplantC2.Priority', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='URL', full_name='clientpb.ImplantC2.URL', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Options', full_name='clientpb.ImplantC2.Options', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=539,
  serialized_end=598,
)


_IMPLANTCONFIG = _descriptor.Descriptor(
  name='ImplantConfig',
  full_name='clientpb.ImplantConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='GOOS', full_name='clientpb.ImplantConfig.GOOS', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='GOARCH', full_name='clientpb.ImplantConfig.GOARCH', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Name', full_name='clientpb.ImplantConfig.Name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='CACert', full_name='clientpb.ImplantConfig.CACert', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Cert', full_name='clientpb.ImplantConfig.Cert', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Key', full_name='clientpb.ImplantConfig.Key', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Debug', full_name='clientpb.ImplantConfig.Debug', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Evasion', full_name='clientpb.ImplantConfig.Evasion', index=7,
      number=31, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ObfuscateSymbols', full_name='clientpb.ImplantConfig.ObfuscateSymbols', index=8,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='WGImplantPrivKey', full_name='clientpb.ImplantConfig.WGImplantPrivKey', index=9,
      number=33, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='WGServerPubKey', full_name='clientpb.ImplantConfig.WGServerPubKey', index=10,
      number=34, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='WGPeerTunIP', full_name='clientpb.ImplantConfig.WGPeerTunIP', index=11,
      number=35, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='WGKeyExchangePort', full_name='clientpb.ImplantConfig.WGKeyExchangePort', index=12,
      number=36, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='WGTcpCommsPort', full_name='clientpb.ImplantConfig.WGTcpCommsPort', index=13,
      number=37, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ReconnectInterval', full_name='clientpb.ImplantConfig.ReconnectInterval', index=14,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='MaxConnectionErrors', full_name='clientpb.ImplantConfig.MaxConnectionErrors', index=15,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='C2', full_name='clientpb.ImplantConfig.C2', index=16,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='CanaryDomains', full_name='clientpb.ImplantConfig.CanaryDomains', index=17,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='LimitDomainJoined', full_name='clientpb.ImplantConfig.LimitDomainJoined', index=18,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='LimitDatetime', full_name='clientpb.ImplantConfig.LimitDatetime', index=19,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='LimitHostname', full_name='clientpb.ImplantConfig.LimitHostname', index=20,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='LimitUsername', full_name='clientpb.ImplantConfig.LimitUsername', index=21,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='LimitFileExists', full_name='clientpb.ImplantConfig.LimitFileExists', index=22,
      number=32, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Format', full_name='clientpb.ImplantConfig.Format', index=23,
      number=25, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='IsSharedLib', full_name='clientpb.ImplantConfig.IsSharedLib', index=24,
      number=26, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='FileName', full_name='clientpb.ImplantConfig.FileName', index=25,
      number=27, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='IsService', full_name='clientpb.ImplantConfig.IsService', index=26,
      number=28, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='IsShellcode', full_name='clientpb.ImplantConfig.IsShellcode', index=27,
      number=29, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _IMPLANTCONFIG_OUTPUTFORMAT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=601,
  serialized_end=1325,
)


_IMPLANTBUILDS_CONFIGSENTRY = _descriptor.Descriptor(
  name='ConfigsEntry',
  full_name='clientpb.ImplantBuilds.ConfigsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='clientpb.ImplantBuilds.ConfigsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='clientpb.ImplantBuilds.ConfigsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1400,
  serialized_end=1471,
)

_IMPLANTBUILDS = _descriptor.Descriptor(
  name='ImplantBuilds',
  full_name='clientpb.ImplantBuilds',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Configs', full_name='clientpb.ImplantBuilds.Configs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_IMPLANTBUILDS_CONFIGSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1328,
  serialized_end=1471,
)


_DELETEREQ = _descriptor.Descriptor(
  name='DeleteReq',
  full_name='clientpb.DeleteReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Name', full_name='clientpb.DeleteReq.Name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1473,
  serialized_end=1498,
)


_DNSCANARY = _descriptor.Descriptor(
  name='DNSCanary',
  full_name='clientpb.DNSCanary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ImplantName', full_name='clientpb.DNSCanary.ImplantName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Domain', full_name='clientpb.DNSCanary.Domain', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Triggered', full_name='clientpb.DNSCanary.Triggered', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='FirstTriggered', full_name='clientpb.DNSCanary.FirstTriggered', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='LatestTrigger', full_name='clientpb.DNSCanary.LatestTrigger', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Count', full_name='clientpb.DNSCanary.Count', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1501,
  serialized_end=1630,
)


_CANARIES = _descriptor.Descriptor(
  name='Canaries',
  full_name='clientpb.Canaries',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Canaries', full_name='clientpb.Canaries.Canaries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1632,
  serialized_end=1681,
)


_UNIQUEWGIP = _descriptor.Descriptor(
  name='UniqueWGIP',
  full_name='clientpb.UniqueWGIP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='IP', full_name='clientpb.UniqueWGIP.IP', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1683,
  serialized_end=1707,
)


_IMPLANTPROFILE = _descriptor.Descriptor(
  name='ImplantProfile',
  full_name='clientpb.ImplantProfile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Name', full_name='clientpb.ImplantProfile.Name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Config', full_name='clientpb.ImplantProfile.Config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1709,
  serialized_end=1780,
)


_IMPLANTPROFILES = _descriptor.Descriptor(
  name='ImplantProfiles',
  full_name='clientpb.ImplantProfiles',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Profiles', full_name='clientpb.ImplantProfiles.Profiles', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1782,
  serialized_end=1843,
)


_REGENERATEREQ = _descriptor.Descriptor(
  name='RegenerateReq',
  full_name='clientpb.RegenerateReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ImplantName', full_name='clientpb.RegenerateReq.ImplantName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1845,
  serialized_end=1881,
)


_JOB = _descriptor.Descriptor(
  name='Job',
  full_name='clientpb.Job',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='clientpb.Job.ID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Name', full_name='clientpb.Job.Name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Description', full_name='clientpb.Job.Description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Protocol', full_name='clientpb.Job.Protocol', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Port', full_name='clientpb.Job.Port', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Domains', full_name='clientpb.Job.Domains', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1883,
  serialized_end=1984,
)


_JOBS = _descriptor.Descriptor(
  name='Jobs',
  full_name='clientpb.Jobs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Active', full_name='clientpb.Jobs.Active', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1986,
  serialized_end=2023,
)


_KILLJOBREQ = _descriptor.Descriptor(
  name='KillJobReq',
  full_name='clientpb.KillJobReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='clientpb.KillJobReq.ID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2025,
  serialized_end=2049,
)


_KILLJOB = _descriptor.Descriptor(
  name='KillJob',
  full_name='clientpb.KillJob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='clientpb.KillJob.ID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Success', full_name='clientpb.KillJob.Success', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2051,
  serialized_end=2089,
)


_MTLSLISTENERREQ = _descriptor.Descriptor(
  name='MTLSListenerReq',
  full_name='clientpb.MTLSListenerReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Host', full_name='clientpb.MTLSListenerReq.Host', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Port', full_name='clientpb.MTLSListenerReq.Port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Persistent', full_name='clientpb.MTLSListenerReq.Persistent', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2091,
  serialized_end=2156,
)


_MTLSLISTENER = _descriptor.Descriptor(
  name='MTLSListener',
  full_name='clientpb.MTLSListener',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='JobID', full_name='clientpb.MTLSListener.JobID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2158,
  serialized_end=2187,
)


_WGLISTENERREQ = _descriptor.Descriptor(
  name='WGListenerReq',
  full_name='clientpb.WGListenerReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Port', full_name='clientpb.WGListenerReq.Port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='TunIP', full_name='clientpb.WGListenerReq.TunIP', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='NPort', full_name='clientpb.WGListenerReq.NPort', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='KeyPort', full_name='clientpb.WGListenerReq.KeyPort', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Persistent', full_name='clientpb.WGListenerReq.Persistent', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2189,
  serialized_end=2285,
)


_WGLISTENER = _descriptor.Descriptor(
  name='WGListener',
  full_name='clientpb.WGListener',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='JobID', full_name='clientpb.WGListener.JobID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2287,
  serialized_end=2314,
)


_DNSLISTENERREQ = _descriptor.Descriptor(
  name='DNSListenerReq',
  full_name='clientpb.DNSListenerReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Domains', full_name='clientpb.DNSListenerReq.Domains', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Canaries', full_name='clientpb.DNSListenerReq.Canaries', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Host', full_name='clientpb.DNSListenerReq.Host', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Port', full_name='clientpb.DNSListenerReq.Port', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Persistent', full_name='clientpb.DNSListenerReq.Persistent', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2316,
  serialized_end=2415,
)


_DNSLISTENER = _descriptor.Descriptor(
  name='DNSListener',
  full_name='clientpb.DNSListener',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='JobID', full_name='clientpb.DNSListener.JobID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2417,
  serialized_end=2445,
)


_HTTPLISTENERREQ = _descriptor.Descriptor(
  name='HTTPListenerReq',
  full_name='clientpb.HTTPListenerReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Domain', full_name='clientpb.HTTPListenerReq.Domain', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Host', full_name='clientpb.HTTPListenerReq.Host', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Port', full_name='clientpb.HTTPListenerReq.Port', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Secure', full_name='clientpb.HTTPListenerReq.Secure', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Website', full_name='clientpb.HTTPListenerReq.Website', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Cert', full_name='clientpb.HTTPListenerReq.Cert', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Key', full_name='clientpb.HTTPListenerReq.Key', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ACME', full_name='clientpb.HTTPListenerReq.ACME', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Persistent', full_name='clientpb.HTTPListenerReq.Persistent', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2448,
  serialized_end=2603,
)


_NAMEDPIPESREQ = _descriptor.Descriptor(
  name='NamedPipesReq',
  full_name='clientpb.NamedPipesReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='PipeName', full_name='clientpb.NamedPipesReq.PipeName', index=0,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='clientpb.NamedPipesReq.Request', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2605,
  serialized_end=2674,
)


_NAMEDPIPES = _descriptor.Descriptor(
  name='NamedPipes',
  full_name='clientpb.NamedPipes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Success', full_name='clientpb.NamedPipes.Success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Err', full_name='clientpb.NamedPipes.Err', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Response', full_name='clientpb.NamedPipes.Response', index=2,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2676,
  serialized_end=2756,
)


_TCPPIVOTREQ = _descriptor.Descriptor(
  name='TCPPivotReq',
  full_name='clientpb.TCPPivotReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Address', full_name='clientpb.TCPPivotReq.Address', index=0,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='clientpb.TCPPivotReq.Request', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2758,
  serialized_end=2824,
)


_TCPPIVOT = _descriptor.Descriptor(
  name='TCPPivot',
  full_name='clientpb.TCPPivot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Success', full_name='clientpb.TCPPivot.Success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Err', full_name='clientpb.TCPPivot.Err', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Response', full_name='clientpb.TCPPivot.Response', index=2,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2826,
  serialized_end=2904,
)


_HTTPLISTENER = _descriptor.Descriptor(
  name='HTTPListener',
  full_name='clientpb.HTTPListener',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='JobID', full_name='clientpb.HTTPListener.JobID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2906,
  serialized_end=2935,
)


_SESSIONS = _descriptor.Descriptor(
  name='Sessions',
  full_name='clientpb.Sessions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Sessions', full_name='clientpb.Sessions.Sessions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2937,
  serialized_end=2984,
)


_UPDATESESSION = _descriptor.Descriptor(
  name='UpdateSession',
  full_name='clientpb.UpdateSession',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='SessionID', full_name='clientpb.UpdateSession.SessionID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Name', full_name='clientpb.UpdateSession.Name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2986,
  serialized_end=3034,
)


_GENERATEREQ = _descriptor.Descriptor(
  name='GenerateReq',
  full_name='clientpb.GenerateReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Config', full_name='clientpb.GenerateReq.Config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3036,
  serialized_end=3090,
)


_GENERATE = _descriptor.Descriptor(
  name='Generate',
  full_name='clientpb.Generate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='File', full_name='clientpb.Generate.File', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3092,
  serialized_end=3132,
)


_MSFREQ = _descriptor.Descriptor(
  name='MSFReq',
  full_name='clientpb.MSFReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Payload', full_name='clientpb.MSFReq.Payload', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='LHost', full_name='clientpb.MSFReq.LHost', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='LPort', full_name='clientpb.MSFReq.LPort', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Encoder', full_name='clientpb.MSFReq.Encoder', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Iterations', full_name='clientpb.MSFReq.Iterations', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='clientpb.MSFReq.Request', index=5,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3135,
  serialized_end=3263,
)


_MSFREMOTEREQ = _descriptor.Descriptor(
  name='MSFRemoteReq',
  full_name='clientpb.MSFRemoteReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Payload', full_name='clientpb.MSFRemoteReq.Payload', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='LHost', full_name='clientpb.MSFRemoteReq.LHost', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='LPort', full_name='clientpb.MSFRemoteReq.LPort', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Encoder', full_name='clientpb.MSFRemoteReq.Encoder', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Iterations', full_name='clientpb.MSFRemoteReq.Iterations', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='PID', full_name='clientpb.MSFRemoteReq.PID', index=5,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='clientpb.MSFRemoteReq.Request', index=6,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3266,
  serialized_end=3413,
)


_STAGERLISTENERREQ = _descriptor.Descriptor(
  name='StagerListenerReq',
  full_name='clientpb.StagerListenerReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Protocol', full_name='clientpb.StagerListenerReq.Protocol', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Host', full_name='clientpb.StagerListenerReq.Host', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Port', full_name='clientpb.StagerListenerReq.Port', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Data', full_name='clientpb.StagerListenerReq.Data', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Cert', full_name='clientpb.StagerListenerReq.Cert', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Key', full_name='clientpb.StagerListenerReq.Key', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ACME', full_name='clientpb.StagerListenerReq.ACME', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3416,
  serialized_end=3561,
)


_STAGERLISTENER = _descriptor.Descriptor(
  name='StagerListener',
  full_name='clientpb.StagerListener',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='JobID', full_name='clientpb.StagerListener.JobID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3563,
  serialized_end=3594,
)


_SHELLCODERDIREQ = _descriptor.Descriptor(
  name='ShellcodeRDIReq',
  full_name='clientpb.ShellcodeRDIReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Data', full_name='clientpb.ShellcodeRDIReq.Data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='FunctionName', full_name='clientpb.ShellcodeRDIReq.FunctionName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Arguments', full_name='clientpb.ShellcodeRDIReq.Arguments', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3596,
  serialized_end=3668,
)


_SHELLCODERDI = _descriptor.Descriptor(
  name='ShellcodeRDI',
  full_name='clientpb.ShellcodeRDI',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Data', full_name='clientpb.ShellcodeRDI.Data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3670,
  serialized_end=3698,
)


_MSFSTAGERREQ = _descriptor.Descriptor(
  name='MsfStagerReq',
  full_name='clientpb.MsfStagerReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Arch', full_name='clientpb.MsfStagerReq.Arch', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Format', full_name='clientpb.MsfStagerReq.Format', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Port', full_name='clientpb.MsfStagerReq.Port', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Host', full_name='clientpb.MsfStagerReq.Host', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='OS', full_name='clientpb.MsfStagerReq.OS', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Protocol', full_name='clientpb.MsfStagerReq.Protocol', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='BadChars', full_name='clientpb.MsfStagerReq.BadChars', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3701,
  serialized_end=3846,
)


_MSFSTAGER = _descriptor.Descriptor(
  name='MsfStager',
  full_name='clientpb.MsfStager',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='File', full_name='clientpb.MsfStager.File', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3848,
  serialized_end=3889,
)


_GETSYSTEMREQ = _descriptor.Descriptor(
  name='GetSystemReq',
  full_name='clientpb.GetSystemReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='HostingProcess', full_name='clientpb.GetSystemReq.HostingProcess', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Config', full_name='clientpb.GetSystemReq.Config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='clientpb.GetSystemReq.Request', index=2,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3891,
  serialized_end=4006,
)


_MIGRATEREQ = _descriptor.Descriptor(
  name='MigrateReq',
  full_name='clientpb.MigrateReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Pid', full_name='clientpb.MigrateReq.Pid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Config', full_name='clientpb.MigrateReq.Config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='clientpb.MigrateReq.Request', index=2,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4008,
  serialized_end=4110,
)


_CREATETUNNELREQ = _descriptor.Descriptor(
  name='CreateTunnelReq',
  full_name='clientpb.CreateTunnelReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Request', full_name='clientpb.CreateTunnelReq.Request', index=0,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4112,
  serialized_end=4165,
)


_CREATETUNNEL = _descriptor.Descriptor(
  name='CreateTunnel',
  full_name='clientpb.CreateTunnel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='SessionID', full_name='clientpb.CreateTunnel.SessionID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='TunnelID', full_name='clientpb.CreateTunnel.TunnelID', index=1,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4167,
  serialized_end=4222,
)


_CLOSETUNNELREQ = _descriptor.Descriptor(
  name='CloseTunnelReq',
  full_name='clientpb.CloseTunnelReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='TunnelID', full_name='clientpb.CloseTunnelReq.TunnelID', index=0,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='clientpb.CloseTunnelReq.Request', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4224,
  serialized_end=4298,
)


_CLIENT = _descriptor.Descriptor(
  name='Client',
  full_name='clientpb.Client',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='clientpb.Client.ID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Name', full_name='clientpb.Client.Name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Operator', full_name='clientpb.Client.Operator', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4300,
  serialized_end=4372,
)


_EVENT = _descriptor.Descriptor(
  name='Event',
  full_name='clientpb.Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='EventType', full_name='clientpb.Event.EventType', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Session', full_name='clientpb.Event.Session', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Job', full_name='clientpb.Event.Job', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Client', full_name='clientpb.Event.Client', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Data', full_name='clientpb.Event.Data', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Err', full_name='clientpb.Event.Err', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4375,
  serialized_end=4526,
)


_OPERATORS = _descriptor.Descriptor(
  name='Operators',
  full_name='clientpb.Operators',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Operators', full_name='clientpb.Operators.Operators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4528,
  serialized_end=4578,
)


_OPERATOR = _descriptor.Descriptor(
  name='Operator',
  full_name='clientpb.Operator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Online', full_name='clientpb.Operator.Online', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Name', full_name='clientpb.Operator.Name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4580,
  serialized_end=4620,
)


_WEBCONTENT = _descriptor.Descriptor(
  name='WebContent',
  full_name='clientpb.WebContent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Path', full_name='clientpb.WebContent.Path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ContentType', full_name='clientpb.WebContent.ContentType', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Size', full_name='clientpb.WebContent.Size', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Content', full_name='clientpb.WebContent.Content', index=3,
      number=9, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4622,
  serialized_end=4704,
)


_WEBSITEADDCONTENT_CONTENTSENTRY = _descriptor.Descriptor(
  name='ContentsEntry',
  full_name='clientpb.WebsiteAddContent.ContentsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='clientpb.WebsiteAddContent.ContentsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='clientpb.WebsiteAddContent.ContentsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4803,
  serialized_end=4872,
)

_WEBSITEADDCONTENT = _descriptor.Descriptor(
  name='WebsiteAddContent',
  full_name='clientpb.WebsiteAddContent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Name', full_name='clientpb.WebsiteAddContent.Name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Contents', full_name='clientpb.WebsiteAddContent.Contents', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_WEBSITEADDCONTENT_CONTENTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4707,
  serialized_end=4872,
)


_WEBSITEREMOVECONTENT = _descriptor.Descriptor(
  name='WebsiteRemoveContent',
  full_name='clientpb.WebsiteRemoveContent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Name', full_name='clientpb.WebsiteRemoveContent.Name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Paths', full_name='clientpb.WebsiteRemoveContent.Paths', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4874,
  serialized_end=4925,
)


_WEBSITE_CONTENTSENTRY = _descriptor.Descriptor(
  name='ContentsEntry',
  full_name='clientpb.Website.ContentsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='clientpb.Website.ContentsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='clientpb.Website.ContentsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4803,
  serialized_end=4872,
)

_WEBSITE = _descriptor.Descriptor(
  name='Website',
  full_name='clientpb.Website',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Name', full_name='clientpb.Website.Name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Contents', full_name='clientpb.Website.Contents', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_WEBSITE_CONTENTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4928,
  serialized_end=5073,
)


_WEBSITES = _descriptor.Descriptor(
  name='Websites',
  full_name='clientpb.Websites',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Websites', full_name='clientpb.Websites.Websites', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5075,
  serialized_end=5122,
)


_WGCLIENTCONFIG = _descriptor.Descriptor(
  name='WGClientConfig',
  full_name='clientpb.WGClientConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ServerPubKey', full_name='clientpb.WGClientConfig.ServerPubKey', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ClientPrivateKey', full_name='clientpb.WGClientConfig.ClientPrivateKey', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ClientPubKey', full_name='clientpb.WGClientConfig.ClientPubKey', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ClientIP', full_name='clientpb.WGClientConfig.ClientIP', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5124,
  serialized_end=5228,
)

_IMPLANTCONFIG.fields_by_name['C2'].message_type = _IMPLANTC2
_IMPLANTCONFIG.fields_by_name['Format'].enum_type = _IMPLANTCONFIG_OUTPUTFORMAT
_IMPLANTCONFIG_OUTPUTFORMAT.containing_type = _IMPLANTCONFIG
_IMPLANTBUILDS_CONFIGSENTRY.fields_by_name['value'].message_type = _IMPLANTCONFIG
_IMPLANTBUILDS_CONFIGSENTRY.containing_type = _IMPLANTBUILDS
_IMPLANTBUILDS.fields_by_name['Configs'].message_type = _IMPLANTBUILDS_CONFIGSENTRY
_CANARIES.fields_by_name['Canaries'].message_type = _DNSCANARY
_IMPLANTPROFILE.fields_by_name['Config'].message_type = _IMPLANTCONFIG
_IMPLANTPROFILES.fields_by_name['Profiles'].message_type = _IMPLANTPROFILE
_JOBS.fields_by_name['Active'].message_type = _JOB
_NAMEDPIPESREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_NAMEDPIPES.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_TCPPIVOTREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_TCPPIVOT.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_SESSIONS.fields_by_name['Sessions'].message_type = _SESSION
_GENERATEREQ.fields_by_name['Config'].message_type = _IMPLANTCONFIG
_GENERATE.fields_by_name['File'].message_type = commonpb_dot_common__pb2._FILE
_MSFREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_MSFREMOTEREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_STAGERLISTENERREQ.fields_by_name['Protocol'].enum_type = _STAGEPROTOCOL
_MSFSTAGERREQ.fields_by_name['Protocol'].enum_type = _STAGEPROTOCOL
_MSFSTAGER.fields_by_name['File'].message_type = commonpb_dot_common__pb2._FILE
_GETSYSTEMREQ.fields_by_name['Config'].message_type = _IMPLANTCONFIG
_GETSYSTEMREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_MIGRATEREQ.fields_by_name['Config'].message_type = _IMPLANTCONFIG
_MIGRATEREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_CREATETUNNELREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_CLOSETUNNELREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_CLIENT.fields_by_name['Operator'].message_type = _OPERATOR
_EVENT.fields_by_name['Session'].message_type = _SESSION
_EVENT.fields_by_name['Job'].message_type = _JOB
_EVENT.fields_by_name['Client'].message_type = _CLIENT
_OPERATORS.fields_by_name['Operators'].message_type = _OPERATOR
_WEBSITEADDCONTENT_CONTENTSENTRY.fields_by_name['value'].message_type = _WEBCONTENT
_WEBSITEADDCONTENT_CONTENTSENTRY.containing_type = _WEBSITEADDCONTENT
_WEBSITEADDCONTENT.fields_by_name['Contents'].message_type = _WEBSITEADDCONTENT_CONTENTSENTRY
_WEBSITE_CONTENTSENTRY.fields_by_name['value'].message_type = _WEBCONTENT
_WEBSITE_CONTENTSENTRY.containing_type = _WEBSITE
_WEBSITE.fields_by_name['Contents'].message_type = _WEBSITE_CONTENTSENTRY
_WEBSITES.fields_by_name['Websites'].message_type = _WEBSITE
DESCRIPTOR.message_types_by_name['Version'] = _VERSION
DESCRIPTOR.message_types_by_name['Session'] = _SESSION
DESCRIPTOR.message_types_by_name['ImplantC2'] = _IMPLANTC2
DESCRIPTOR.message_types_by_name['ImplantConfig'] = _IMPLANTCONFIG
DESCRIPTOR.message_types_by_name['ImplantBuilds'] = _IMPLANTBUILDS
DESCRIPTOR.message_types_by_name['DeleteReq'] = _DELETEREQ
DESCRIPTOR.message_types_by_name['DNSCanary'] = _DNSCANARY
DESCRIPTOR.message_types_by_name['Canaries'] = _CANARIES
DESCRIPTOR.message_types_by_name['UniqueWGIP'] = _UNIQUEWGIP
DESCRIPTOR.message_types_by_name['ImplantProfile'] = _IMPLANTPROFILE
DESCRIPTOR.message_types_by_name['ImplantProfiles'] = _IMPLANTPROFILES
DESCRIPTOR.message_types_by_name['RegenerateReq'] = _REGENERATEREQ
DESCRIPTOR.message_types_by_name['Job'] = _JOB
DESCRIPTOR.message_types_by_name['Jobs'] = _JOBS
DESCRIPTOR.message_types_by_name['KillJobReq'] = _KILLJOBREQ
DESCRIPTOR.message_types_by_name['KillJob'] = _KILLJOB
DESCRIPTOR.message_types_by_name['MTLSListenerReq'] = _MTLSLISTENERREQ
DESCRIPTOR.message_types_by_name['MTLSListener'] = _MTLSLISTENER
DESCRIPTOR.message_types_by_name['WGListenerReq'] = _WGLISTENERREQ
DESCRIPTOR.message_types_by_name['WGListener'] = _WGLISTENER
DESCRIPTOR.message_types_by_name['DNSListenerReq'] = _DNSLISTENERREQ
DESCRIPTOR.message_types_by_name['DNSListener'] = _DNSLISTENER
DESCRIPTOR.message_types_by_name['HTTPListenerReq'] = _HTTPLISTENERREQ
DESCRIPTOR.message_types_by_name['NamedPipesReq'] = _NAMEDPIPESREQ
DESCRIPTOR.message_types_by_name['NamedPipes'] = _NAMEDPIPES
DESCRIPTOR.message_types_by_name['TCPPivotReq'] = _TCPPIVOTREQ
DESCRIPTOR.message_types_by_name['TCPPivot'] = _TCPPIVOT
DESCRIPTOR.message_types_by_name['HTTPListener'] = _HTTPLISTENER
DESCRIPTOR.message_types_by_name['Sessions'] = _SESSIONS
DESCRIPTOR.message_types_by_name['UpdateSession'] = _UPDATESESSION
DESCRIPTOR.message_types_by_name['GenerateReq'] = _GENERATEREQ
DESCRIPTOR.message_types_by_name['Generate'] = _GENERATE
DESCRIPTOR.message_types_by_name['MSFReq'] = _MSFREQ
DESCRIPTOR.message_types_by_name['MSFRemoteReq'] = _MSFREMOTEREQ
DESCRIPTOR.message_types_by_name['StagerListenerReq'] = _STAGERLISTENERREQ
DESCRIPTOR.message_types_by_name['StagerListener'] = _STAGERLISTENER
DESCRIPTOR.message_types_by_name['ShellcodeRDIReq'] = _SHELLCODERDIREQ
DESCRIPTOR.message_types_by_name['ShellcodeRDI'] = _SHELLCODERDI
DESCRIPTOR.message_types_by_name['MsfStagerReq'] = _MSFSTAGERREQ
DESCRIPTOR.message_types_by_name['MsfStager'] = _MSFSTAGER
DESCRIPTOR.message_types_by_name['GetSystemReq'] = _GETSYSTEMREQ
DESCRIPTOR.message_types_by_name['MigrateReq'] = _MIGRATEREQ
DESCRIPTOR.message_types_by_name['CreateTunnelReq'] = _CREATETUNNELREQ
DESCRIPTOR.message_types_by_name['CreateTunnel'] = _CREATETUNNEL
DESCRIPTOR.message_types_by_name['CloseTunnelReq'] = _CLOSETUNNELREQ
DESCRIPTOR.message_types_by_name['Client'] = _CLIENT
DESCRIPTOR.message_types_by_name['Event'] = _EVENT
DESCRIPTOR.message_types_by_name['Operators'] = _OPERATORS
DESCRIPTOR.message_types_by_name['Operator'] = _OPERATOR
DESCRIPTOR.message_types_by_name['WebContent'] = _WEBCONTENT
DESCRIPTOR.message_types_by_name['WebsiteAddContent'] = _WEBSITEADDCONTENT
DESCRIPTOR.message_types_by_name['WebsiteRemoveContent'] = _WEBSITEREMOVECONTENT
DESCRIPTOR.message_types_by_name['Website'] = _WEBSITE
DESCRIPTOR.message_types_by_name['Websites'] = _WEBSITES
DESCRIPTOR.message_types_by_name['WGClientConfig'] = _WGCLIENTCONFIG
DESCRIPTOR.enum_types_by_name['StageProtocol'] = _STAGEPROTOCOL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Version = _reflection.GeneratedProtocolMessageType('Version', (_message.Message,), {
  'DESCRIPTOR' : _VERSION,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.Version)
  })
_sym_db.RegisterMessage(Version)

Session = _reflection.GeneratedProtocolMessageType('Session', (_message.Message,), {
  'DESCRIPTOR' : _SESSION,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.Session)
  })
_sym_db.RegisterMessage(Session)

ImplantC2 = _reflection.GeneratedProtocolMessageType('ImplantC2', (_message.Message,), {
  'DESCRIPTOR' : _IMPLANTC2,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.ImplantC2)
  })
_sym_db.RegisterMessage(ImplantC2)

ImplantConfig = _reflection.GeneratedProtocolMessageType('ImplantConfig', (_message.Message,), {
  'DESCRIPTOR' : _IMPLANTCONFIG,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.ImplantConfig)
  })
_sym_db.RegisterMessage(ImplantConfig)

ImplantBuilds = _reflection.GeneratedProtocolMessageType('ImplantBuilds', (_message.Message,), {

  'ConfigsEntry' : _reflection.GeneratedProtocolMessageType('ConfigsEntry', (_message.Message,), {
    'DESCRIPTOR' : _IMPLANTBUILDS_CONFIGSENTRY,
    '__module__' : 'clientpb.client_pb2'
    # @@protoc_insertion_point(class_scope:clientpb.ImplantBuilds.ConfigsEntry)
    })
  ,
  'DESCRIPTOR' : _IMPLANTBUILDS,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.ImplantBuilds)
  })
_sym_db.RegisterMessage(ImplantBuilds)
_sym_db.RegisterMessage(ImplantBuilds.ConfigsEntry)

DeleteReq = _reflection.GeneratedProtocolMessageType('DeleteReq', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREQ,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.DeleteReq)
  })
_sym_db.RegisterMessage(DeleteReq)

DNSCanary = _reflection.GeneratedProtocolMessageType('DNSCanary', (_message.Message,), {
  'DESCRIPTOR' : _DNSCANARY,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.DNSCanary)
  })
_sym_db.RegisterMessage(DNSCanary)

Canaries = _reflection.GeneratedProtocolMessageType('Canaries', (_message.Message,), {
  'DESCRIPTOR' : _CANARIES,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.Canaries)
  })
_sym_db.RegisterMessage(Canaries)

UniqueWGIP = _reflection.GeneratedProtocolMessageType('UniqueWGIP', (_message.Message,), {
  'DESCRIPTOR' : _UNIQUEWGIP,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.UniqueWGIP)
  })
_sym_db.RegisterMessage(UniqueWGIP)

ImplantProfile = _reflection.GeneratedProtocolMessageType('ImplantProfile', (_message.Message,), {
  'DESCRIPTOR' : _IMPLANTPROFILE,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.ImplantProfile)
  })
_sym_db.RegisterMessage(ImplantProfile)

ImplantProfiles = _reflection.GeneratedProtocolMessageType('ImplantProfiles', (_message.Message,), {
  'DESCRIPTOR' : _IMPLANTPROFILES,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.ImplantProfiles)
  })
_sym_db.RegisterMessage(ImplantProfiles)

RegenerateReq = _reflection.GeneratedProtocolMessageType('RegenerateReq', (_message.Message,), {
  'DESCRIPTOR' : _REGENERATEREQ,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.RegenerateReq)
  })
_sym_db.RegisterMessage(RegenerateReq)

Job = _reflection.GeneratedProtocolMessageType('Job', (_message.Message,), {
  'DESCRIPTOR' : _JOB,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.Job)
  })
_sym_db.RegisterMessage(Job)

Jobs = _reflection.GeneratedProtocolMessageType('Jobs', (_message.Message,), {
  'DESCRIPTOR' : _JOBS,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.Jobs)
  })
_sym_db.RegisterMessage(Jobs)

KillJobReq = _reflection.GeneratedProtocolMessageType('KillJobReq', (_message.Message,), {
  'DESCRIPTOR' : _KILLJOBREQ,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.KillJobReq)
  })
_sym_db.RegisterMessage(KillJobReq)

KillJob = _reflection.GeneratedProtocolMessageType('KillJob', (_message.Message,), {
  'DESCRIPTOR' : _KILLJOB,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.KillJob)
  })
_sym_db.RegisterMessage(KillJob)

MTLSListenerReq = _reflection.GeneratedProtocolMessageType('MTLSListenerReq', (_message.Message,), {
  'DESCRIPTOR' : _MTLSLISTENERREQ,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.MTLSListenerReq)
  })
_sym_db.RegisterMessage(MTLSListenerReq)

MTLSListener = _reflection.GeneratedProtocolMessageType('MTLSListener', (_message.Message,), {
  'DESCRIPTOR' : _MTLSLISTENER,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.MTLSListener)
  })
_sym_db.RegisterMessage(MTLSListener)

WGListenerReq = _reflection.GeneratedProtocolMessageType('WGListenerReq', (_message.Message,), {
  'DESCRIPTOR' : _WGLISTENERREQ,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.WGListenerReq)
  })
_sym_db.RegisterMessage(WGListenerReq)

WGListener = _reflection.GeneratedProtocolMessageType('WGListener', (_message.Message,), {
  'DESCRIPTOR' : _WGLISTENER,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.WGListener)
  })
_sym_db.RegisterMessage(WGListener)

DNSListenerReq = _reflection.GeneratedProtocolMessageType('DNSListenerReq', (_message.Message,), {
  'DESCRIPTOR' : _DNSLISTENERREQ,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.DNSListenerReq)
  })
_sym_db.RegisterMessage(DNSListenerReq)

DNSListener = _reflection.GeneratedProtocolMessageType('DNSListener', (_message.Message,), {
  'DESCRIPTOR' : _DNSLISTENER,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.DNSListener)
  })
_sym_db.RegisterMessage(DNSListener)

HTTPListenerReq = _reflection.GeneratedProtocolMessageType('HTTPListenerReq', (_message.Message,), {
  'DESCRIPTOR' : _HTTPLISTENERREQ,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.HTTPListenerReq)
  })
_sym_db.RegisterMessage(HTTPListenerReq)

NamedPipesReq = _reflection.GeneratedProtocolMessageType('NamedPipesReq', (_message.Message,), {
  'DESCRIPTOR' : _NAMEDPIPESREQ,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.NamedPipesReq)
  })
_sym_db.RegisterMessage(NamedPipesReq)

NamedPipes = _reflection.GeneratedProtocolMessageType('NamedPipes', (_message.Message,), {
  'DESCRIPTOR' : _NAMEDPIPES,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.NamedPipes)
  })
_sym_db.RegisterMessage(NamedPipes)

TCPPivotReq = _reflection.GeneratedProtocolMessageType('TCPPivotReq', (_message.Message,), {
  'DESCRIPTOR' : _TCPPIVOTREQ,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.TCPPivotReq)
  })
_sym_db.RegisterMessage(TCPPivotReq)

TCPPivot = _reflection.GeneratedProtocolMessageType('TCPPivot', (_message.Message,), {
  'DESCRIPTOR' : _TCPPIVOT,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.TCPPivot)
  })
_sym_db.RegisterMessage(TCPPivot)

HTTPListener = _reflection.GeneratedProtocolMessageType('HTTPListener', (_message.Message,), {
  'DESCRIPTOR' : _HTTPLISTENER,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.HTTPListener)
  })
_sym_db.RegisterMessage(HTTPListener)

Sessions = _reflection.GeneratedProtocolMessageType('Sessions', (_message.Message,), {
  'DESCRIPTOR' : _SESSIONS,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.Sessions)
  })
_sym_db.RegisterMessage(Sessions)

UpdateSession = _reflection.GeneratedProtocolMessageType('UpdateSession', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESESSION,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.UpdateSession)
  })
_sym_db.RegisterMessage(UpdateSession)

GenerateReq = _reflection.GeneratedProtocolMessageType('GenerateReq', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEREQ,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.GenerateReq)
  })
_sym_db.RegisterMessage(GenerateReq)

Generate = _reflection.GeneratedProtocolMessageType('Generate', (_message.Message,), {
  'DESCRIPTOR' : _GENERATE,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.Generate)
  })
_sym_db.RegisterMessage(Generate)

MSFReq = _reflection.GeneratedProtocolMessageType('MSFReq', (_message.Message,), {
  'DESCRIPTOR' : _MSFREQ,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.MSFReq)
  })
_sym_db.RegisterMessage(MSFReq)

MSFRemoteReq = _reflection.GeneratedProtocolMessageType('MSFRemoteReq', (_message.Message,), {
  'DESCRIPTOR' : _MSFREMOTEREQ,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.MSFRemoteReq)
  })
_sym_db.RegisterMessage(MSFRemoteReq)

StagerListenerReq = _reflection.GeneratedProtocolMessageType('StagerListenerReq', (_message.Message,), {
  'DESCRIPTOR' : _STAGERLISTENERREQ,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.StagerListenerReq)
  })
_sym_db.RegisterMessage(StagerListenerReq)

StagerListener = _reflection.GeneratedProtocolMessageType('StagerListener', (_message.Message,), {
  'DESCRIPTOR' : _STAGERLISTENER,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.StagerListener)
  })
_sym_db.RegisterMessage(StagerListener)

ShellcodeRDIReq = _reflection.GeneratedProtocolMessageType('ShellcodeRDIReq', (_message.Message,), {
  'DESCRIPTOR' : _SHELLCODERDIREQ,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.ShellcodeRDIReq)
  })
_sym_db.RegisterMessage(ShellcodeRDIReq)

ShellcodeRDI = _reflection.GeneratedProtocolMessageType('ShellcodeRDI', (_message.Message,), {
  'DESCRIPTOR' : _SHELLCODERDI,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.ShellcodeRDI)
  })
_sym_db.RegisterMessage(ShellcodeRDI)

MsfStagerReq = _reflection.GeneratedProtocolMessageType('MsfStagerReq', (_message.Message,), {
  'DESCRIPTOR' : _MSFSTAGERREQ,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.MsfStagerReq)
  })
_sym_db.RegisterMessage(MsfStagerReq)

MsfStager = _reflection.GeneratedProtocolMessageType('MsfStager', (_message.Message,), {
  'DESCRIPTOR' : _MSFSTAGER,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.MsfStager)
  })
_sym_db.RegisterMessage(MsfStager)

GetSystemReq = _reflection.GeneratedProtocolMessageType('GetSystemReq', (_message.Message,), {
  'DESCRIPTOR' : _GETSYSTEMREQ,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.GetSystemReq)
  })
_sym_db.RegisterMessage(GetSystemReq)

MigrateReq = _reflection.GeneratedProtocolMessageType('MigrateReq', (_message.Message,), {
  'DESCRIPTOR' : _MIGRATEREQ,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.MigrateReq)
  })
_sym_db.RegisterMessage(MigrateReq)

CreateTunnelReq = _reflection.GeneratedProtocolMessageType('CreateTunnelReq', (_message.Message,), {
  'DESCRIPTOR' : _CREATETUNNELREQ,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.CreateTunnelReq)
  })
_sym_db.RegisterMessage(CreateTunnelReq)

CreateTunnel = _reflection.GeneratedProtocolMessageType('CreateTunnel', (_message.Message,), {
  'DESCRIPTOR' : _CREATETUNNEL,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.CreateTunnel)
  })
_sym_db.RegisterMessage(CreateTunnel)

CloseTunnelReq = _reflection.GeneratedProtocolMessageType('CloseTunnelReq', (_message.Message,), {
  'DESCRIPTOR' : _CLOSETUNNELREQ,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.CloseTunnelReq)
  })
_sym_db.RegisterMessage(CloseTunnelReq)

Client = _reflection.GeneratedProtocolMessageType('Client', (_message.Message,), {
  'DESCRIPTOR' : _CLIENT,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.Client)
  })
_sym_db.RegisterMessage(Client)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), {
  'DESCRIPTOR' : _EVENT,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.Event)
  })
_sym_db.RegisterMessage(Event)

Operators = _reflection.GeneratedProtocolMessageType('Operators', (_message.Message,), {
  'DESCRIPTOR' : _OPERATORS,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.Operators)
  })
_sym_db.RegisterMessage(Operators)

Operator = _reflection.GeneratedProtocolMessageType('Operator', (_message.Message,), {
  'DESCRIPTOR' : _OPERATOR,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.Operator)
  })
_sym_db.RegisterMessage(Operator)

WebContent = _reflection.GeneratedProtocolMessageType('WebContent', (_message.Message,), {
  'DESCRIPTOR' : _WEBCONTENT,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.WebContent)
  })
_sym_db.RegisterMessage(WebContent)

WebsiteAddContent = _reflection.GeneratedProtocolMessageType('WebsiteAddContent', (_message.Message,), {

  'ContentsEntry' : _reflection.GeneratedProtocolMessageType('ContentsEntry', (_message.Message,), {
    'DESCRIPTOR' : _WEBSITEADDCONTENT_CONTENTSENTRY,
    '__module__' : 'clientpb.client_pb2'
    # @@protoc_insertion_point(class_scope:clientpb.WebsiteAddContent.ContentsEntry)
    })
  ,
  'DESCRIPTOR' : _WEBSITEADDCONTENT,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.WebsiteAddContent)
  })
_sym_db.RegisterMessage(WebsiteAddContent)
_sym_db.RegisterMessage(WebsiteAddContent.ContentsEntry)

WebsiteRemoveContent = _reflection.GeneratedProtocolMessageType('WebsiteRemoveContent', (_message.Message,), {
  'DESCRIPTOR' : _WEBSITEREMOVECONTENT,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.WebsiteRemoveContent)
  })
_sym_db.RegisterMessage(WebsiteRemoveContent)

Website = _reflection.GeneratedProtocolMessageType('Website', (_message.Message,), {

  'ContentsEntry' : _reflection.GeneratedProtocolMessageType('ContentsEntry', (_message.Message,), {
    'DESCRIPTOR' : _WEBSITE_CONTENTSENTRY,
    '__module__' : 'clientpb.client_pb2'
    # @@protoc_insertion_point(class_scope:clientpb.Website.ContentsEntry)
    })
  ,
  'DESCRIPTOR' : _WEBSITE,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.Website)
  })
_sym_db.RegisterMessage(Website)
_sym_db.RegisterMessage(Website.ContentsEntry)

Websites = _reflection.GeneratedProtocolMessageType('Websites', (_message.Message,), {
  'DESCRIPTOR' : _WEBSITES,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.Websites)
  })
_sym_db.RegisterMessage(Websites)

WGClientConfig = _reflection.GeneratedProtocolMessageType('WGClientConfig', (_message.Message,), {
  'DESCRIPTOR' : _WGCLIENTCONFIG,
  '__module__' : 'clientpb.client_pb2'
  # @@protoc_insertion_point(class_scope:clientpb.WGClientConfig)
  })
_sym_db.RegisterMessage(WGClientConfig)


DESCRIPTOR._options = None
_IMPLANTBUILDS_CONFIGSENTRY._options = None
_CREATETUNNEL.fields_by_name['TunnelID']._options = None
_CLOSETUNNELREQ.fields_by_name['TunnelID']._options = None
_WEBCONTENT.fields_by_name['Size']._options = None
_WEBSITEADDCONTENT_CONTENTSENTRY._options = None
_WEBSITE_CONTENTSENTRY._options = None
# @@protoc_insertion_point(module_scope)
